@@ -3,7 +3,7 @@ use warnings;
 
 package WebService::Nestoria::Search;
 BEGIN {
-  $WebService::Nestoria::Search::VERSION = '1.020000';
+  $WebService::Nestoria::Search::VERSION = '1.020001';
 }
 
 use Carp;
@@ -16,7 +16,7 @@ WebService::Nestoria::Search - Perl interface to the Nestoria Search public API.
 
 =head1 VERSION
 
-version 1.020000
+version 1.020001
 
 =head1 SYNOPSIS
 
@@ -163,7 +163,6 @@ my %Config = (
         'es'                  => 'http://api.nestoria.es/api',
         'de'                  => 'http://api.nestoria.de/api',
         'it'                  => 'http://api.nestoria.it/api',
-        'au'                  => 'http://api.nestoria.com.au/api',
         'fr'                  => 'http://api.nestoria.fr/api',
         'br'                  => 'http://api.nestoria.com.br/api',
         'in'                  => 'http://api.nestoria.in/api',
@@ -636,8 +635,6 @@ Currently the available countries are:
 
 =item * fr - France
 
-=item * au - Australia
-
 =item * br - Brazil
 
 =item * in - India
